@@ -121,11 +121,11 @@ class HitcounterAdapter:
             request = self.context.request
         if not self.requestFromBrowser(request):
             return 0   
-        if 0:  #do not use cookie for a moment
+        if 1:  #do not use cookie for a moment
             if request:
                 cookie_name = self.context.absolute_url()
-                if request.has_key(cookie_name):
-                    return
+                if request.cookies.get(cookie_name):
+                    return self.getHitCount(key=key)
                 request.response.setCookie(cookie_name, 1)
         if key:
             if 0: #block hits summapr for now
